summaryrefslogtreecommitdiffstats
path: root/superkaramba/examples
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-23 01:42:07 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-23 01:42:07 +0000
commita2277b6bc715464e83882b90c2a058139b8a6b54 (patch)
treeab09b14014f59b4d8e2ddd12226aa0b22e4dfc5d /superkaramba/examples
parentd3f79e04b34bd1f70a458b81b28fc8799498c8dc (diff)
downloadtdeutils-a2277b6bc715464e83882b90c2a058139b8a6b54.tar.gz
tdeutils-a2277b6bc715464e83882b90c2a058139b8a6b54.zip
TQt4 port kdeutils
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeutils@1238125 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'superkaramba/examples')
-rw-r--r--superkaramba/examples/api.html6
-rw-r--r--superkaramba/examples/globalMouse/extension/xcursor.c4
-rw-r--r--superkaramba/examples/globalMouse/eyes.py2
-rw-r--r--superkaramba/examples/globalMouse/eyes.theme2
-rw-r--r--superkaramba/examples/richtext/richtext.py4
-rw-r--r--superkaramba/examples/taskBar/cleanbar/cleanbar.py4
-rwxr-xr-xsuperkaramba/examples/test_all.sh2
-rw-r--r--superkaramba/examples/unicode/unicode.py6
8 files changed, 15 insertions, 15 deletions
diff --git a/superkaramba/examples/api.html b/superkaramba/examples/api.html
index 132544a..14c2263 100644
--- a/superkaramba/examples/api.html
+++ b/superkaramba/examples/api.html
@@ -165,7 +165,7 @@ Widget/createWidgetMask</a></h2>
<p>[<a href="#robo_top_of_doc">top</a>]</p>
<p><strong>SYNOPSIS</strong></p>
-<span class="SYNOPSIS"><p> long <strong>createWidgetMask</strong>(widget, mask)
+<span class="SYNOPSIS"><p> long <strong>createWidgetMask</strong>(widget, tqmask)
</p>
</span><p><strong>DESCRIPTION</strong></p>
<span class="DESCRIPTION"><p> This function doesn't work currently due to a bug in KDE. Please use
@@ -174,7 +174,7 @@ Widget/createWidgetMask</a></h2>
</span><p><strong>ARGUMENTS</strong></p>
<span class="ARGUMENTS"><ul><li> long widget -- karamba
</li>
-<li> string mask -- The name of the widget mask file.
+<li> string tqmask -- The name of the widget tqmask file.
</li>
</ul>
<p></p>
@@ -2096,7 +2096,7 @@ Misc/translateAll</a></h2>
</p>
</span><p><strong>DESCRIPTION</strong></p>
<span class="DESCRIPTION"><p> Moves all widgets within a theme in a particular direction relative from
- the previous spot without moving the parent theme widget.
+ the previous spot without moving the tqparent theme widget.
</p>
</span><p><strong>ARGUMENTS</strong></p>
<span class="ARGUMENTS"><ul><li> long widget -- karamba
diff --git a/superkaramba/examples/globalMouse/extension/xcursor.c b/superkaramba/examples/globalMouse/extension/xcursor.c
index 8dad240..3de7ae3 100644
--- a/superkaramba/examples/globalMouse/extension/xcursor.c
+++ b/superkaramba/examples/globalMouse/extension/xcursor.c
@@ -47,7 +47,7 @@ static PyObject* xcursor_position(self, args)
char* display_name;
int root_x_return, root_y_return;
int win_x_return, win_y_return;
- unsigned int mask_return;
+ unsigned int tqmask_return;
if (! (display_name = getenv("DISPLAY")) )
{
@@ -83,7 +83,7 @@ static PyObject* xcursor_position(self, args)
XQueryPointer(display, root, &root_return, &child_return,
&root_x_return, &root_y_return,
&win_x_return, &win_y_return,
- &mask_return);
+ &tqmask_return);
/* return Python Object */
return Py_BuildValue("(i,i)", root_x_return, root_y_return);
diff --git a/superkaramba/examples/globalMouse/eyes.py b/superkaramba/examples/globalMouse/eyes.py
index b95f86d..64bc3e0 100644
--- a/superkaramba/examples/globalMouse/eyes.py
+++ b/superkaramba/examples/globalMouse/eyes.py
@@ -108,7 +108,7 @@ def widgetUpdated(widget):
#f.close()
- #karamba.createWidgetMask(widget, theme_path + "pics/mask.png")
+ #karamba.createWidgetMask(widget, theme_path + "pics/tqmask.png")
linkePupille = karamba.createImage(widget, 15, 30, theme_path + "pics/pupille.png")
rechtePupille = karamba.createImage(widget, 100, 30, theme_path + "pics/pupille.png")
diff --git a/superkaramba/examples/globalMouse/eyes.theme b/superkaramba/examples/globalMouse/eyes.theme
index 4f2417b..ffdff73 100644
--- a/superkaramba/examples/globalMouse/eyes.theme
+++ b/superkaramba/examples/globalMouse/eyes.theme
@@ -1,3 +1,3 @@
-KARAMBA X=5 Y=850 W=167 H=111 MASK="pics/mask.png" LOCKED=false INTERVAL=100
+KARAMBA X=5 Y=850 W=167 H=111 MASK="pics/tqmask.png" LOCKED=false INTERVAL=100
IMAGE X=0 Y=0 PATH="pics/eyes.png"
diff --git a/superkaramba/examples/taskBar/cleanbar/cleanbar.py b/superkaramba/examples/taskBar/cleanbar/cleanbar.py
index c0da2a2..40478c0 100644
--- a/superkaramba/examples/taskBar/cleanbar/cleanbar.py
+++ b/superkaramba/examples/taskBar/cleanbar/cleanbar.py
@@ -43,9 +43,9 @@ i = 0
for x in output:
param = x.split()
if (len(param) > 1):
- if param[0].find("Width:") != -1:
+ if param[0].tqfind("Width:") != -1:
resX = int(param[1])
- if param[0].find("Height:") != -1:
+ if param[0].tqfind("Height:") != -1:
resY = int(param[1])
diff --git a/superkaramba/examples/test_all.sh b/superkaramba/examples/test_all.sh
index 5e95063..cdf192d 100755
--- a/superkaramba/examples/test_all.sh
+++ b/superkaramba/examples/test_all.sh
@@ -10,7 +10,7 @@ themes=(
"richtext/richtext.theme"
"richtext/rtext.theme"
"globalMouse/eyes.theme"
- "unicode/unicode.theme"
+ "tqunicode/tqunicode.theme"
"mouseDrag/karmix/karmix.theme"
"input_api/input_api.theme"
"input_example/input_example.theme"
diff --git a/superkaramba/examples/richtext/richtext.py b/superkaramba/examples/richtext/richtext.py
index 518aa65..11fe9d7 100644
--- a/superkaramba/examples/richtext/richtext.py
+++ b/superkaramba/examples/richtext/richtext.py
@@ -1,6 +1,6 @@
#Unicode Example
#For Symbol Tables look at www.unicode.org/charts/
hidden = 0
@@ -35,7 +35,7 @@ is used to encode the formatting commands.</p>
<li>Hyperlinks: <a href="kfmclient openURL http://netdragon.sourceforge.net"> Superkaramba Homepage</a></li>
<li>Links can also <a href="#trigger">trigger</a> actions in the script</li>
<li><i>Various</i> <b>different</b> <u>caracter</u> <s>styles</s></li>
-<li><a href="kfmclient openURL http://www.unicode.org">Unicode</a>: \u03B6 \u03B3 \u03BB \u03A3 \u03A9 </li>
+<li><a href="kfmclient openURL http://www.tqunicode.org">Unicode</a>: \u03B6 \u03B3 \u03BB \u03A3 \u03A9 </li>
<li>Simple Tables:
<table bgcolor="darkgray" border="1" width="80%">
<tr><th colspan="3">Header</th></tr>
@@ -1,6 +1,6 @@
#Unicode Example
-#For Symbol Tables look at www.unicode.org/charts/
+#For Symbol Tables look at www.tqunicode.org/charts/
hidden = 0
diff --git a/superkaramba/examples/unicode/unicode.py b/superkaramba/examples/unicode/unicode.py
index 13d1136..1a15f83 100644
--- a/superkaramba/examples/unicode/unicode.py
+++ b/superkaramba/examples/unicode/unicode.py
@@ -1,6 +1,6 @@
#Unicode Example
#For Symbol Tables look at www.unicode.org/charts/
#this import statement allows access to the karamba functions
@@ -31,8 +31,8 @@ def initWidget(widget):
\u0631\u0632\u0633\u0634\u0635\u0636\u0637\u0638\u0639\u063A\u0641\u0642\u0643\u0644\u0645\u0646
\u0647\u0648\u064A
<p>
-For a complete reference on unicode caracter codes look at:
-<center><a href="kfmclient openURL http://www.unicode.org/charts/">www.unicode.org/charts/</a></center>
+For a complete reference on tqunicode caracter codes look at:
+<center><a href="kfmclient openURL http://www.tqunicode.org/charts/">www.tqunicode.org/charts/</a></center>
</p>
"""
karamba.resizeWidget(widget, 400, 400)
@@ -1,6 +1,6 @@
#Unicode Example
-#For Symbol Tables look at www.unicode.org/charts/
+#For Symbol Tables look at www.tqunicode.org/charts/
#this import statement allows access to the karamba functions